class LogSeverity:
    TRACE = 0
    DEBUG = 1
    INFO = 2
    WARN = 3
    ERROR = 4
    FATAL = 5


class AlertType:
    ZVEI = "zvei"
    FAX = "fax"
    SDS = "sds"
